T81 Foundation

Changelog

Source of Truth: This document defines the history of changes released to the public. For future plans, see ../process/roadmaps-plans/ROADMAP.md.

All notable changes to this project are documented in this file.

The format is based on Keep a Changelog.

[Unreleased]

[1.3.2] - 2026-03-08

Added

Fixed

Changed

Added

Fixed

Changed

Build/CI

Notes